<?php
namespace BWDBackToTop;

use BWDBackToTop\PageSettings\Page_Settings;
define( "BWDBTT_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDBTT_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class BWDBackToTop {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdbtt_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdbtt_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdbtt_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdbtt_back_to_top_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/back_to_top.php' );
	}

	public function bwdbtt_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDBTTBackToTop() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/back_to_top_manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdbtt_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwd-back-to-top-category',
			[
				'title' => esc_html__( 'BWD Back To Top', 'bwd-back-to-top' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdbtt_all_assets_for_the_public(){
		wp_enqueue_script( 'bwdbtt_back_top_main_one_js', plugin_dir_url( __FILE__ ) . 'assets/public/js/main.js', array('jquery'), '1.0', true );
		wp_enqueue_script( 'bwdbtt_back_top_main_one_js', plugin_dir_url( __FILE__ ) . 'assets/public/js/jquery-3.6.0.min.js', array('jquery'), '1.0', true );
		$all_css_js_file = array(
            'bwdbtt_back_top_plugin_main_css' => array('bwdbtt_path_define'=>BWDBTT_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),
            'bwdbtt_back_top_plugin_fontawesome_css' => array('bwdbtt_path_define'=>BWDBTT_TEST_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/all.min.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdbtt_path_define'], null, '1.0', 'all');
        }
	}
	public function bwdbtt_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdbtt_back_top_admin_main_css' => array('bwdbtt_path_admin_define'=>BWDBTT_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdbtt_path_admin_define'], null, '1.0', 'all');
        }
	}
	
	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdbtt_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdbtt_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdbtt_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdbtt_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdbtt_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
BWDBackToTop::instance();